@@ -8,6 +8,7 @@ import os.path
 import geopandas as gpd
 import shapely
 import numpy as np
+from haversine import inverse_haversine, Direction
 
 
 def main():
@@ -26,8 +27,8 @@ Converts a shape file (.shp) to a gridded csv file.
     arg_parser.add_argument(
         "--cell-size",
         type=float,
-        help="Cell size, in lat/long segments. Default: 0.1",
-        default=0.1,
+        help="Cell size, in kilometers. Default: 10",
+        default=10.0,
     )
 
     # Parse arguments and
@@ -47,18 +48,21 @@ Converts a shape file (.shp) to a gridded csv file.
     columns = [col for col in shp.columns if col != "geometry"]
 
     # Determine geometric values
-    cell_width = args.cell_size
-    cell_height = args.cell_size
     xmin, ymin, xmax, ymax = shp.total_bounds
 
     # Build list of boxes representing the grid that covers the full shape image rectangle
     grid_cells = []
-    for x0 in np.arange(xmin, xmax + cell_width, cell_width):
-        for y0 in np.arange(ymin, ymax + cell_height, cell_height):
-            x1 = x0 - cell_width
-            y1 = y0 + cell_height
-            new_cell = shapely.geometry.box(x0, y0, x1, y1)
-            grid_cells.append(new_cell)
+    x, y = xmin, ymin
+    while y < ymax:
+        next_y = inverse_haversine((x, y), args.cell_size, Direction.EAST)[1]
+        while x < xmax:
+            next_x = inverse_haversine((x, y), args.cell_size, Direction.NORTH)[0]
+            grid_cells.append(
+                shapely.geometry.box(x, y, next_x, next_y)
+            )
+            x = next_x
+        x = xmin
+        y = next_y
 
     # Create a GeoDataFrame based on the grid cells, setting a value that represents the center of the cell
     gridded = gpd.GeoDataFrame(geometry=grid_cells)
